@@ -25,27 +25,16 @@
 char *text;
 
 /* External functions and data */
-extern void init_global_key(void);
-extern stats *text_stats;
-extern float *slft_std;
-extern float *bift_std;
-extern float *trift_std;
-float *load_slft_std(char *filename);
-float *load_bift_std(char *filename);
-float *load_trift_std(char *filename);
 void build_gui(void);
-void apply_global_key_text(void);
+void load_plugins(void);
+
 int main (int argc, char *argv[]) {
-    init_global_key();
 
-    /* Load the standard frequency tables */
-    slft_std = load_slft_std(DEFAULT_SLFT);
-    bift_std = load_bift_std(DEFAULT_BIFT);
-    trift_std = load_trift_std(DEFAULT_TRIFT);
-    
     gtk_init(&argc, &argv);
+
+    load_plugins();
+    
     build_gui();
-    apply_global_key_text();
     gtk_main();
     
     exit(0);
