@@ -19,6 +19,9 @@
  * USA
  */
 
+#ifndef H_CRANK
+#define H_CRANK
+
 #include <gtk/gtk.h>
 #include <gmodule.h>
 #include <ctype.h>
@@ -33,7 +36,7 @@
 #include <dirent.h> 
 #endif
 
-#define VERSION "0.1.1"
+#define VERSION "0.1.4"
 #define INTERFACE_VERSION 1
 
 #define TOGGLE(x) (x = ((x) ? FALSE : TRUE))
@@ -46,9 +49,6 @@
                   "============\n\n" \
                   "Author: Matthew Russell <twig5151@yahoo.com>\n" \
                   "Crank Homepage: http://crank.sourceforge.net/\n" 
-#define STR_START_TEXT "Crank v" VERSION
-
-#define PLUGIN_DIR "plugins"
 
 typedef struct _plugin_data {
     char *name; 
@@ -57,17 +57,22 @@ typedef struct _plugin_data {
     char *description;
     int interface_version;                      /* Version of the interface used by the plugin */
     int plugin_type;                            /* Floating or mode? */
+    char *menu_string;                          /* Full path to menu in ItemFactory notation */
     int (*boot) (void);                         /* Function run at startup */
     void (*init_plugin) (void);                 /* Initialise data structures when new instance is created */
     void (*deactivate_plugin) (void);           /* Clean up after plugin is removed */
     GtkWidget *(*make_widget) (char *);         /* Make user interface component */
     char *(*transform) (char *);                /* Perform transformation on some text */ 
     void (*reset) (void);                       /* Reset a mode plugin to a hopefully neutral effect */
+    float (*fitness) (char *);                  /* Evaluate the closeness of a text to plaintext */
     struct _plugin_data *next;
 } plugin_data;
 
-#define PLUGIN_MODE     1
-#define PLUGIN_FLOATING 2
+#define PLUGIN_MODE     1 /* A plugin which transforms the source according to a user interface control */
+#define PLUGIN_FLOATING 2 /* A plugin which displays a dialog display independantly of the current mode plugin */
+#define PLUGIN_FITNESS  3 /* A plugin which provides a fitness evaluation function for text being plaintext */
 
 #define PLUGIN_BOOT_OK   1
 #define PLUGIN_BOOT_FAIL 2
+
+#endif
