@@ -19,6 +19,9 @@
  * USA
  */
 
+#ifndef H_COMMON_MONOALPHABETIC
+#define H_COMMON_MONOALPHABETIC
+
 #define UPPER_KEY_BOUND ((int) ('Z' + 1))
 typedef char key[UPPER_KEY_BOUND];
 
@@ -34,3 +37,4 @@ void key_reverse(key *k);
 void key_invert(key *k);
 void key_clear (key *k);
 void key_complete (key *k);
+#endif
