@@ -24,6 +24,10 @@
 /* External functions and variables */
 extern char *text;
 extern GtkWidget *textarea;
+extern GtkWidget *sourcearea;
+extern GtkWidget *hbox2;
+extern GtkWidget *label_source_area;
+extern int displaying_sourcearea;
 extern plugin_data *current_plugin;
 
 GtkWidget *make_OK_box(const char *text);
@@ -32,6 +36,35 @@ int do_save (char *filename);
 void do_break(void);
 GtkWidget *make_source_edit_dialog(void);
 void display_text(void);
+void display_source_text(void);
+
+/* Empty the source text */
+void cb_clear_source(void) {
+    free(text);
+    text = malloc(sizeof(char));
+    text[0] = '\0';
+    display_source_text();
+    display_text();
+}
+
+/* Change some of the source */
+void cb_source_change(GtkEditable *editable, gpointer user_data) {
+    free(text);
+    text = gtk_editable_get_chars(GTK_EDITABLE(sourcearea), 0, -1);
+    display_text();
+}
+
+/* Hide / show source view */
+void cb_toggle_source_view(void) {
+    if (displaying_sourcearea) {
+	gtk_widget_hide(hbox2);
+	gtk_widget_hide(label_source_area);
+    } else {
+	gtk_widget_show(hbox2);
+	gtk_widget_show(label_source_area);
+    }
+    TOGGLE(displaying_sourcearea);
+}
 
 /* Make source = view */
 void cb_set_source_from_view(GtkWidget *widget, gpointer gdata) {
@@ -39,17 +72,7 @@ void cb_set_source_from_view(GtkWidget *widget, gpointer gdata) {
     text = gtk_editable_get_chars(GTK_EDITABLE(textarea), 0, -1);
     current_plugin->reset();
     display_text();
-}
-
-/* Edit source */
-void cb_open_edit_source_dialog(GtkWidget *widget, gpointer gdata) {
-    gtk_widget_show(make_source_edit_dialog());
-}
-
-void cb_ok_edit_source(GtkWidget *widget, gpointer gdata) {
-    free(text);
-    text = gtk_editable_get_chars(GTK_EDITABLE(gdata), 0, -1);
-    display_text();
+    display_source_text();
 }
 
 /* Help - about */
@@ -64,6 +87,7 @@ void cb_open(GtkWidget *widget, GtkFileSelection *fselection) {
 	gtk_widget_show(make_OK_box("ERROR: Unable to find or open file."));
     current_plugin->reset();
     display_text();
+    display_source_text();
 }
 
 void cb_save(GtkWidget *widget, GtkFileSelection *fselection) {
