@@ -21,8 +21,18 @@
 
 #include "crank.h"
 
+extern char *text;
+extern GtkWidget *sourcearea;
+
 /* Let the user interface perform any needed updates */
 void yield_to_ui(void) {
     while (gtk_events_pending())
 	gtk_main_iteration();
 }
+
+/* Refresh source textarea */
+void display_source_text(void) {
+    gtk_text_set_point(GTK_TEXT(sourcearea), 0);
+    gtk_text_forward_delete(GTK_TEXT(sourcearea), gtk_text_get_length(GTK_TEXT(sourcearea)));
+    gtk_text_insert(GTK_TEXT(sourcearea), NULL, NULL, NULL, text, strlen(text));
+}
